@@ -1502,23 +1502,33 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		.executeWithCallback(new RowCallback<String, String>() {
 			@Override
 			public void success(Rows<String, String> rows) {
-				synchronized (commentsByUser) {
-					nextRow: for (Row<String, String> row : rows) {
-						for(Column<String> column: row.getColumns())
-							if(column.getName().equals("Userid")){
-								if(column.getStringValue().equals(userid)){
-									try{
-										Comment c = readCommentById(row.getKey());
-										Feed f = readFeed(c.getFeedid());
-										if(c.getTime().getTime() >= timeInMillis && 
-												(f.getType() == FeedType.TWEET || f.getType() == FeedType.SHARE || f.getType() == FeedType.PUBLISH))
-											commentsByUser.add(c);
-									}catch(Exception e){
-										_log.error("Unable to read comment with id" + row.getKey(), e);
-									}
+
+				// use a temporary list for each thread
+				List<Comment> partialCommentsList = new ArrayList<Comment>();
+
+				nextRow: for (Row<String, String> row : rows) {
+					for(Column<String> column: row.getColumns()){
+						if(column.getName().equals("Userid")){
+							if(column.getStringValue().equals(userid)){
+								try{
+									Comment c = readCommentById(row.getKey());
+									Feed f = readFeed(c.getFeedid());
+									if(c.getTime().getTime() >= timeInMillis && 
+											(f.getType() == FeedType.TWEET || f.getType() == FeedType.SHARE || f.getType() == FeedType.PUBLISH))
+										partialCommentsList.add(c);
+								}catch(Exception e){
+									_log.error("Unable to read comment with id" + row.getKey(), e);
 								}
-								continue nextRow;
 							}
+							continue nextRow;
+						}
+					}
+				}
+
+				// if there is something to save...
+				if(partialCommentsList.size() > 0){
+					synchronized (commentsByUser){
+						commentsByUser.addAll(partialCommentsList);
 					}
 				}
 			}
@@ -1528,12 +1538,11 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 				// decrement value
 				int currentValue = maxRetryExecutions.decrementAndGet();
 				if(currentValue <= 0){
-					_log.error("Error while fetching user's recent comments ... repeating operation");
-					return true;  
-				}else
-				{
 					_log.error("Too many errors while fetching user's comments, exiting");
 					return false; 
+				}else{
+					_log.error("Error while fetching user's recent comments ... repeating operation");
+					return true;  
 				}
 			}
 		});
@@ -1735,8 +1744,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		// get the list of liked feeds
 		List<String> likedFeedsIdsByUser = getAllLikedFeedIdsByUser(userid);
 
-		if(likedFeedsIdsByUser != null){
-
+		if(likedFeedsIdsByUser != null && !likedFeedsIdsByUser.isEmpty()){
 			for(int i = likedFeedsIdsByUser.size() - 1; i >= 0; i--){
 				String feedId = likedFeedsIdsByUser.get(i);
 				try{
