@@ -7,9 +7,11 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Set;
 
 import org.gcube.vomanagement.usermanagement.GroupManager;
 import org.gcube.vomanagement.usermanagement.exception.GroupRetrievalFault;
@@ -21,13 +23,15 @@ import org.gcube.vomanagement.usermanagement.exception.VirtualGroupNotExistingEx
 import org.gcube.vomanagement.usermanagement.model.CustomAttributeKeys;
 import org.gcube.vomanagement.usermanagement.model.GCubeGroup;
 import org.gcube.vomanagement.usermanagement.model.GCubeRole;
+import org.gcube.vomanagement.usermanagement.model.GroupMembershipType;
 import org.gcube.vomanagement.usermanagement.model.VirtualGroup;
 import org.gcube.vomanagement.usermanagement.util.ManagementUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import com.liferay.portal.kernel.exception.PortalException;
 import com.liferay.portal.kernel.exception.SystemException;
+import com.liferay.portal.kernel.log.Log;
+import com.liferay.portal.kernel.log.LogFactoryUtil;
+import com.liferay.portal.kernel.util.StringBundler;
 import com.liferay.portal.model.Group;
 import com.liferay.portal.model.GroupConstants;
 import com.liferay.portal.model.Role;
@@ -42,6 +46,7 @@ import com.liferay.portal.service.RoleServiceUtil;
 import com.liferay.portal.service.ServiceContext;
 import com.liferay.portal.service.UserLocalServiceUtil;
 import com.liferay.portal.util.PortalUtil;
+import com.liferay.portal.webserver.WebServerServletTokenUtil;
 import com.liferay.portlet.expando.model.ExpandoBridge;
 import com.liferay.portlet.expando.util.ExpandoBridgeFactoryUtil;
 
@@ -49,14 +54,13 @@ public class LiferayGroupManager implements GroupManager {
 	/**
 	 * logger
 	 */
-	private static final Logger _log = LoggerFactory.getLogger(LiferayGroupManager.class);
-
+	private static final Log _log = LogFactoryUtil.getLog(LiferayGroupManager.class);
 	// group mapping
 	private GCubeGroup mapLRGroup(Group g) throws PortalException, SystemException, UserManagementSystemException, GroupRetrievalFault {
 		if (g != null) {
 			long logoId = LayoutSetLocalServiceUtil.getLayoutSet(g.getGroupId(), true).getLogoId();
 			if (isVRE(g.getGroupId())) {
-				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, null, g.getType()==GroupConstants.TYPE_SITE_RESTRICTED);
+				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, null, getMappedGroupMembershipType(g.getType()));
 			}
 			else if (isVO(g.getGroupId())) {
 				List<GCubeGroup> vres = new ArrayList<GCubeGroup>();
@@ -64,13 +68,13 @@ public class LiferayGroupManager implements GroupManager {
 				for (Group vre : VREs) {
 					vres.add(mapLRGroup(vre));
 				}
-				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, vres, g.getType()==GroupConstants.TYPE_SITE_RESTRICTED);
+				return new GCubeGroup(g.getGroupId(), g.getParentGroupId(), g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, vres, getMappedGroupMembershipType(g.getType()));
 			} else if (isRootVO(g.getGroupId())) {
 				List<GCubeGroup> vos = new ArrayList<GCubeGroup>();
 				List<Group> children = g.getChildren(true);
 				for (Group vo : children) 
 					vos.add(mapLRGroup(vo));
-				return new GCubeGroup(g.getGroupId(), -1, g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, vos, g.getType()==GroupConstants.TYPE_SITE_RESTRICTED);
+				return new GCubeGroup(g.getGroupId(), -1, g.getName(), g.getDescription(), g.getFriendlyURL(), logoId, vos, getMappedGroupMembershipType(g.getType()));
 			} else{
 				_log.warn("This groupId does not correspond to a VO ora VRE");
 				return null;
@@ -79,6 +83,21 @@ public class LiferayGroupManager implements GroupManager {
 		else 
 			return null;
 	}
+	/**
+	 * 
+	 * @param type
+	 * @return the correspondent mapping to the gcube model
+	 */
+	private GroupMembershipType getMappedGroupMembershipType(int type) {
+		switch (type) {
+		case GroupConstants.TYPE_SITE_RESTRICTED:
+			return GroupMembershipType.RESTRICTED;
+		case GroupConstants.TYPE_SITE_OPEN:
+			return GroupMembershipType.OPEN;
+		default:
+			return GroupMembershipType.PRIVATE;
+		}
+	}
 	/**
 	 * 
 	 * @param groupName
@@ -392,6 +411,26 @@ public class LiferayGroupManager implements GroupManager {
 	 * {@inheritDoc}
 	 */
 	@Override
+	public Set<GCubeGroup> listGroupsByUserAndSite(long userId, final String serverName) throws UserRetrievalFault, UserManagementSystemException, GroupRetrievalFault, VirtualGroupNotExistingException {
+		Set<GCubeGroup> toReturn = new HashSet<>();
+		try {
+			List<VirtualGroup> currSiteVirtualGroups = ManagementUtils.getVirtualGroupsBySiteGroupId(ManagementUtils.getSiteGroupIdFromServletRequest(serverName));
+			for (GCubeGroup userGroup : listGroupsByUser(userId)) {
+				if (isVRE(userGroup.getGroupId())) {
+					for (VirtualGroup vg : currSiteVirtualGroups) 
+						if (getVirtualGroup(userGroup.getGroupId()).getName().compareTo(vg.getName()) == 0) 
+							toReturn.add(userGroup);
+				}
+			}
+		} catch (Exception e) {
+			e.printStackTrace();
+		}		
+		return toReturn;
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
 	public Map<GCubeGroup, List<GCubeRole>> listGroupsAndRolesByUser(long userId) throws UserManagementSystemException {
 		Map<GCubeGroup, List<GCubeRole>> toReturn = new HashMap<GCubeGroup, List<GCubeRole>>();
 		try {
@@ -561,7 +600,7 @@ public class LiferayGroupManager implements GroupManager {
 	private void doAsAdmin() {
 		try {			
 			User admin = LiferayUserManager.getAdmin();
-			_log.info("Admin found: " + admin.getScreenName());
+			_log.debug("Admin found: " + admin.getScreenName());
 			long userId = admin.getUserId();
 			PrincipalThreadLocal.setName(userId);
 			PermissionChecker permissionChecker = PermissionCheckerFactoryUtil.create(UserLocalServiceUtil.getUser(userId));
@@ -598,5 +637,21 @@ public class LiferayGroupManager implements GroupManager {
 	private static String getCatalinaHome() {
 		return (System.getenv("CATALINA_HOME").endsWith("/") ? System.getenv("CATALINA_HOME") : System.getenv("CATALINA_HOME")+"/");
 	}
-	
+	/**
+	 * {@inheritDoc}
+	 */
+	public String getGroupLogoURL(long logoId) {
+		String layoutSetLogo = "";
+		StringBundler sb = new StringBundler(5);
+		String imagePath=PortalUtil.getPathImage();
+		sb.append(imagePath);
+		sb.append("/layout_set_logo?img_id=");
+		sb.append(logoId);
+		sb.append("&t=");
+		sb.append(WebServerServletTokenUtil.getToken(logoId));
+		layoutSetLogo = sb.toString();
+		return layoutSetLogo;
+	}
+
+
 }
